# -*- coding: utf-8 -*-
from setuphelpers import *
import json

# Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls

bin_contains = "OpenJDK11U"
bin_type = "jre"


def update_package():
    # Declaring local variables
    arch = control.architecture
    result = False
    proxies = get_proxies()

    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    # api : https://api.adoptium.net/q/swagger-ui/#/Assets/searchReleases
    url_api = "https://api.adoptium.net/v3/assets/feature_releases/11/ga?architecture=x64&heap_size=normal&image_type=jre&jvm_impl=hotspot&os=mac&page=0&page_size=10&project=jdk&sort_method=DEFAULT&sort_order=DESC&vendor=eclipse"

    # Getting latest version information from official sources
    print("API used is: %s" % url_api)
    json_load = json.loads(wgets(url_api, proxies=proxies))

    found = False

    for releases in json_load:
        if found:
            break
        for binary in releases["binaries"]:
            if (
                bin_contains.lower() in binary["installer"]["link"].lower()
                and binary["image_type"].lower() == bin_type.lower()
                and binary["architecture"].lower() == "x64"
                and binary["installer"]["link"].endswith(".pkg")
            ):
                version = binary["scm_ref"].split("jdk-")[1].split("_")[0].replace("+", "0")
                url_dl = binary["installer"]["link"]
                latest_bin = url_dl.rsplit("/", 1)[1]
                found = True
                break

    print("Latest %s version is: %s" % (app_name, version))
    print("Download URL  is: %s" % url_dl)
    # Downloading latest  binaries
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(url_dl, latest_bin, proxies=proxies)

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.version = "%s-%s" % (Version(version), control.version.split("-", 1)[-1])
    # control.set_software_version(version)
    control.save_control_to_wapt()
    # renaming binary
    os.rename(latest_bin, bin_contains + version + ".pkg")
    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating update-package-sources
    return result
